@@ -64,7 +64,7 @@ use namespace::autoclean;
 
 # PODNAME: Dist::Zilla::Plugin::Manifest::Write
 # ABSTRACT: Have annotated MANIFEST in your distribution
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::BeforeBuild';
@@ -630,7 +630,11 @@ sub _does_role {
     try {
         $ok = $package->meta->does_role( 'Dist::Zilla::Role::' . $role );
     } catch {
-        $self->log_debug( "$_" );
+        my $ex = "$_";
+        chomp( $ex );
+        $self->log_debug( [ 'Can\'t check if plugin %s does role %s:', $plugin, $role ] );
+        $self->log_debug( [ '    %s', $ex ] );
+        $self->log_debug( [ 'Seems %s is not a plugin or not a loaded module', $plugin ] );
     };
     return $ok;
 };
@@ -696,7 +700,7 @@ Dist::Zilla::Plugin::Manifest::Write - Have annotated MANIFEST in your distribut
 
 =head1 VERSION
 
-Version 0.007, released on 2015-08-09 17:57 UTC.
+Version 0.008, released on 2015-08-10 14:37 UTC.
 
 =head1 WHAT?
 
